@@ -1,12 +1,12 @@
 /*
-**  Copyright (c) 2004-2006 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2004-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dk-filter.c,v 1.158 2006/05/19 21:42:05 msk Exp $
+**  $Id: dk-filter.c,v 1.162 2007/03/13 18:10:40 msk Exp $
 */
 
 #ifndef lint
-static char dk_filter_c_id[] = "@(#)$Id: dk-filter.c,v 1.158 2006/05/19 21:42:05 msk Exp $";
+static char dk_filter_c_id[] = "@(#)$Id: dk-filter.c,v 1.162 2007/03/13 18:10:40 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -1582,15 +1582,7 @@ mlfi_eoh(SMFICTX *ctx)
 
 	dfc->mctx_jobid = smfi_getsymval(ctx, "i");
 	if (dfc->mctx_jobid == NULL)
-	{
-		if (no_i_whine && dolog)
-		{
-			syslog(LOG_WARNING,
-			       "WARNING: sendmail symbol 'i' not available");
-			no_i_whine = FALSE;
-		}
 		dfc->mctx_jobid = JOBIDUNKNOWN;
-	}
 
 #if _FFR_REQUIRED_HEADERS
 	/* if requested, verify RFC2822-required headers */
@@ -1625,6 +1617,8 @@ mlfi_eoh(SMFICTX *ctx)
 	}
 #endif /* _FFR_REQUIRED_HEADERS */
 
+	msgsigned = (dkf_findheader(dfc, DK_SIGNHEADER, 0) != NULL);
+
 	/* find the Sender: or From: header */
 	memset(addr, '\0', sizeof addr);
 	from = dkf_findheader(dfc, "Sender", 0);
@@ -1639,7 +1633,8 @@ mlfi_eoh(SMFICTX *ctx)
 			       dfc->mctx_jobid);
 		}
 
-		dfc->mctx_addheader = TRUE;
+		if (msgsigned)
+			dfc->mctx_addheader = TRUE;
 		dfc->mctx_headeronly = TRUE;
 		dfc->mctx_status = DKF_STATUS_BADFORMAT;
 		return SMFIS_CONTINUE;
@@ -1669,7 +1664,6 @@ mlfi_eoh(SMFICTX *ctx)
 	originok = FALSE;
 
 	/* is it a domain we sign for? */
-	msgsigned = (dkf_findheader(dfc, DK_SIGNHEADER, 0) != NULL);
 	if (!msgsigned && domains != NULL && dfc->mctx_domain != NULL)
 	{
 		int n;
@@ -2076,6 +2070,26 @@ mlfi_eom(SMFICTX *ctx)
 	dfc = cc->cctx_msg;
 	assert(dfc != NULL);
 
+	/*
+	**  If necessary, try again to get the job ID in case it came down
+	**  later than expected (e.g. postfix).
+	*/
+
+	if (dfc->mctx_jobid == JOBIDUNKNOWN)
+	{
+		dfc->mctx_jobid = smfi_getsymval(ctx, "i");
+		if (dfc->mctx_jobid == NULL)
+		{
+			if (no_i_whine && dolog)
+			{
+				syslog(LOG_WARNING,
+				       "WARNING: sendmail symbol 'i' not available");
+				no_i_whine = FALSE;
+			}
+			dfc->mctx_jobid = JOBIDUNKNOWN;
+		}
+	}
+
 	/* get hostname; used in the X header and in new MIME boundaries */
 	hostname = smfi_getsymval(ctx, "j");
 	if (hostname == NULL)
@@ -3493,7 +3507,20 @@ main(int argc, char **argv)
 
 		(void) endpwent();
 
-		if (setuid(pw->pw_uid) != 0)
+		if (setgid(pw->pw_gid) != 0)
+		{
+			if (dolog)
+			{
+				syslog(LOG_ERR, "setgid(): %s",
+				       strerror(errno));
+			}
+
+			fprintf(stderr, "%s: setgid(): %s\n", progname,
+			        strerror(errno));
+
+			return EX_NOPERM;
+		}
+		else if (setuid(pw->pw_uid) != 0)
 		{
 			if (dolog)
 			{
