@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2005 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 1998-2007 Sendmail, Inc. and its suppliers.
  *	All rights reserved.
  * Copyright (c) 1983, 1995-1997 Eric P. Allman.  All rights reserved.
  * Copyright (c) 1988, 1993
@@ -10,14 +10,16 @@
  * the sendmail distribution.
  *
  *
- *	$Id: conf.h,v 1.120 2005/03/22 22:07:53 ca Exp $
+ *	$Id: conf.h,v 1.131 2007/03/01 18:06:17 ca Exp $
  */
 
 /*
 **  CONF.H -- All user-configurable parameters for sendmail
 **
-**	Send updates to sendmail@Sendmail.ORG so they will be
-**	included in the next release.
+**	Send updates to Sendmail.ORG so they will be
+**	included in the next release; see
+**	http://www.sendmail.org/email-addresses.html
+**	for current e-mail address.
 */
 
 #ifndef SM_CONF_H
@@ -163,6 +165,8 @@ extern void	hard_syslog();
 */
 
 # ifdef _AIX5
+#  include <sys/signal.h>
+#  include <sys/wait.h>
 #  define _AIX4		40300
 #  define SOCKADDR_LEN_T socklen_t /* e.g., arg#3 to accept, getsockname */
 #  define SOCKOPT_LEN_T	socklen_t /* arg#5 to getsockopt */
@@ -409,6 +413,9 @@ typedef int		pid_t;
 #   if SOLARIS >= 20500 || (SOLARIS < 10000 && SOLARIS >= 205)
 #    define HASSETREUID	1		/* setreuid works as of 2.5 */
 #    define HASSETREGID	1	/* use setregid(2) to set saved gid */
+#   if SOLARIS >= 20600 || (SOLARIS < 10000 && SOLARIS >= 206)
+#    define HASSNPRINTF 1	/* has snprintf(3c) starting in 2.6 */
+#   endif /* SOLARIS >= 20600 || (SOLARIS < 10000 && SOLARIS >= 206) */
 #    if SOLARIS < 207 || (SOLARIS > 10000 && SOLARIS < 20700)
 #     ifndef LA_TYPE
 #      define LA_TYPE	LA_KSTAT	/* use kstat(3k) -- may work in < 2.5 */
@@ -444,6 +451,7 @@ typedef int		pid_t;
 #     define SMRSH_CMDDIR	"/var/adm/sm.bin"
 #    endif /* ! SMRSH_CMDDIR */
 #    define SL_FUDGE	34	/* fudge offset for SyslogPrefixLen */
+#    define HASLDAPGETALIASBYNAME	1	/* added in S8 */
 #   endif /* SOLARIS >= 20800 || (SOLARIS < 10000 && SOLARIS >= 208) */
 #   if SOLARIS >= 20900 || (SOLARIS < 10000 && SOLARIS >= 209)
 #    define HASURANDOMDEV	1	/* /dev/[u]random added in S9 */
@@ -737,8 +745,8 @@ typedef int		pid_t;
 #  define HASFLOCK		1	/* has flock(2) */
 #  define HASUNAME		1	/* has uname(2) */
 #  define HASUNSETENV		1	/* has unsetenv(3) */
-#  define HASSETSID	1	/* has POSIX setsid(2) call */
-#  define HASINITGROUPS	1	/* has initgroups(3) */
+#  define HASSETSID		1	/* has POSIX setsid(2) call */
+#  define HASINITGROUPS		1	/* has initgroups(3) */
 #  define HASSETVBUF		1	/* has setvbuf (3) */
 #  define HASSETREUID		0	/* setreuid(2) unusable */
 #  define HASSETEUID		1	/* has seteuid(2) */
@@ -751,13 +759,22 @@ typedef int		pid_t;
 #  define HASWAITPID		1	/* has waitpid(2) */
 #  define HASGETDTABLESIZE	1	/* has getdtablesize(2) */
 #  define HAS_ST_GEN		1	/* has st_gen field in struct stat */
-#  define HASURANDOMDEV	1	/* has urandom(4) */
+#  define HASURANDOMDEV		1	/* has urandom(4) */
 #  define HASSTRERROR		1	/* has strerror(3) */
 #  define HASGETUSERSHELL	1	/* had getusershell(3) */
 #  define GIDSET_T		gid_t	/* getgroups(2) takes gid_t */
 #  define LA_TYPE		LA_SUBR	/* use getloadavg(3) */
 #  define SFS_TYPE		SFS_MOUNT	/* use <sys/mount.h> statfs() impl */
-#  define SPT_TYPE		SPT_PSSTRINGS	/* use magic PS_STRINGS pointer for setproctitle */
+#  if DARWIN >= 70000
+#   define SOCKADDR_LEN_T	socklen_t
+#  endif
+#  if DARWIN >= 80000
+#   define SPT_TYPE		SPT_REUSEARGV
+#   define SPT_PADCHAR		'\0'
+#   define SOCKOPT_LEN_T	socklen_t
+#  else
+#   define SPT_TYPE		SPT_PSSTRINGS	/* use magic PS_STRINGS pointer for setproctitle */
+#  endif
 #  define ERRLIST_PREDEFINED		/* don't declare sys_errlist */
 #  define BSD4_4_SOCKADDR		/* struct sockaddr has sa_len */
 #  define SAFENFSPATHCONF	0	/* unverified: pathconf(2) doesn't work on NFS */
@@ -776,7 +793,7 @@ extern unsigned int sleepX __P((unsigned int seconds));
 **	See also BSD defines.
 */
 
-# if defined(BSD4_4) && !defined(__bsdi__) && !defined(__GNU__)
+# if defined(BSD4_4) && !defined(__bsdi__) && !defined(__GNU__) && !defined(DARWIN)
 #  include <paths.h>
 #  define HASUNSETENV	1	/* has unsetenv(3) call */
 #  define USESETEUID	1	/* has usable seteuid(2) call */
@@ -794,7 +811,7 @@ extern unsigned int sleepX __P((unsigned int seconds));
 #  endif /* ! LA_TYPE */
 #  define SFS_TYPE	SFS_MOUNT	/* use <sys/mount.h> statfs() impl */
 #  define SPT_TYPE	SPT_PSSTRINGS	/* use PS_STRINGS pointer */
-# endif /* defined(BSD4_4) && !defined(__bsdi__) && !defined(__GNU__) */
+# endif /* defined(BSD4_4) && !defined(__bsdi__) && !defined(__GNU__) && !defined(DARWIN)*/
 
 
 /*
@@ -902,11 +919,14 @@ extern unsigned int sleepX __P((unsigned int seconds));
 #  define NETLINK	1	/* supports AF_LINK */
 #  define SAFENFSPATHCONF 1	/* pathconf(2) pessimizes on NFS filesystems */
 #  define GIDSET_T	gid_t
-#  define QUAD_T		unsigned long long
+#  define QUAD_T	unsigned long long
+#  define HASSNPRINTF	1	/* has snprintf(3) (all versions?) */
 #  ifndef LA_TYPE
 #   define LA_TYPE	LA_SUBR
 #  endif /* ! LA_TYPE */
-#  if defined(__NetBSD__) && defined(__NetBSD_Version__) && __NetBSD_Version__ >= 200040000
+#  if defined(__NetBSD__) && defined(__NetBSD_Version__) && \
+    ((__NetBSD_Version__ >= 200040000 && __NetBSD_Version__ < 200090000) || \
+    (__NetBSD_Version__ >= 299000900))
 #   undef SFS_TYPE
 #   define SFS_TYPE	SFS_STATVFS
 #  else
@@ -922,7 +942,9 @@ extern unsigned int sleepX __P((unsigned int seconds));
 #  if defined(__NetBSD__) && defined(__NetBSD_Version__) && __NetBSD_Version__ >= 104170000
 #   define HASSETUSERCONTEXT	1	/* BSDI-style login classes */
 #  endif
-#  if defined(__NetBSD__) && defined(__NetBSD_Version__) && __NetBSD_Version__ >= 200060000
+#  if defined(__NetBSD__) && defined(__NetBSD_Version__) && \
+    ((__NetBSD_Version__ >= 200060000 && __NetBSD_Version__ < 200090000) || \
+    (__NetBSD_Version__ >= 299000900))
 #   define HASCLOSEFROM	1	/* closefrom(3) added in 2.0F */
 #  endif
 #  if defined(__NetBSD__)
@@ -997,6 +1019,9 @@ extern unsigned int sleepX __P((unsigned int seconds));
 #   if OpenBSD >= 200405
 #    define HASCLOSEFROM	1	/* closefrom(3) added in 3.5 */
 #   endif /* OpenBSD >= 200405 */
+#   if OpenBSD >= 200505
+#    undef NETISO	/* iso.h removed in 3.7 */
+#   endif /* OpenBSD >= 200505 */
 #  endif /* defined(__OpenBSD__) */
 # endif /* defined(__DragonFly__) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) */
 
