@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char ar_c_id[] = "@(#)$Id: ar.c,v 1.58 2006/05/03 18:20:26 msk Exp $";
+static char ar_c_id[] = "@(#)$Id: ar.c,v 1.60 2006/09/16 23:00:59 msk Exp $";
 #endif /* !lint */
 
 /* OS stuff */
@@ -26,6 +26,7 @@ static char ar_c_id[] = "@(#)$Id: ar.c,v 1.58 2006/05/03 18:20:26 msk Exp $";
 #include <arpa/nameser.h>
 #include <ctype.h>
 #include <resolv.h>
+#include <netdb.h>
 #include <stdlib.h>
 #include <time.h>
 #include <errno.h>
@@ -67,7 +68,6 @@ static char ar_c_id[] = "@(#)$Id: ar.c,v 1.58 2006/05/03 18:20:26 msk Exp $";
 
 /* ar includes */
 #include "ar.h"
-#include "fix.h"
 
 /*
 **  DATA TYPES
@@ -138,6 +138,13 @@ struct ar_libhandle
 
 static void *ar_malloc(AR_LIB, size_t);
 static void ar_free(AR_LIB lib, void *ptr);
+static int ar_res_init(void);
+
+/*
+**  INTERNAL GLOBALS
+*/
+
+static struct __res_state ar_res;
 
 /*
 **  ========================= PRIVATE FUNCTIONS =========================
@@ -599,9 +606,15 @@ ar_sendquery(AR_LIB lib, AR_QUERY query)
 	
 	for (;;)
 	{
+#if (defined(__RES) && (__RES <= 19960801))
 		n = res_mkquery(QUERY, query->q_name, query->q_class,
 		                query->q_type, NULL, 0, NULL, lib->ar_querybuf,
 		                lib->ar_querybuflen);
+#else /* defined(__RES) && (__RES <= 19960801) */
+		n = res_nmkquery(&ar_res, QUERY, query->q_name, query->q_class,
+		                query->q_type, NULL, 0, NULL, lib->ar_querybuf,
+		                lib->ar_querybuflen);
+#endif /* defined(__RES) && (__RES <= 19960801) */
 
 		if (n != (size_t) -1)
 		{
@@ -1092,6 +1105,39 @@ ar_dispatcher(void *tp)
 	return NULL;
 }
 
+/*
+**  AR_RES_INIT -- res_init()/res_ninit() wrapper
+**
+**  Parameters:
+**  	None.
+**
+**  Return value:
+**  	Return value from the resolver library; see res_init(3).
+*/
+
+static int
+ar_res_init(void)
+{
+	h_errno = NETDB_SUCCESS;
+
+	memset(&ar_res, '\0', sizeof ar_res);
+
+#ifdef AR_RES_MANUAL
+	ar_res_manual(&ar_res);
+#else /* AR_RES_MANUAL */
+# if (defined(__RES) && (__RES <= 19960801))
+	/* old-school (bind4) */
+	res_init();
+	memcpy(&ar_res, &_res, sizeof ar_res);
+# else /* defined(__RES) && (__RES <= 19960801) */
+	/* new-school (bind8 and up) */
+	(void) res_ninit(&ar_res);
+# endif /* defined(__RES) && (__RES <= 19960801) */
+#endif /* AR_RES_MANUAL */
+
+	return h_errno;
+}
+
 /*
 **  ========================= PUBLIC FUNCTIONS =========================
 */
@@ -1129,7 +1175,7 @@ ar_init(ar_malloc_t user_malloc, ar_free_t user_free, void *user_closure,
 
 	ar_res_init();
 
-	new->ar_nscount = _res.nscount;
+	new->ar_nscount = ar_res.nscount;
 	new->ar_malloc = user_malloc;
 	new->ar_free = user_free;
 	new->ar_closure = user_closure;
@@ -1147,9 +1193,9 @@ ar_init(ar_malloc_t user_malloc, ar_free_t user_free, void *user_closure,
 	new->ar_control[1] = -1;
 	new->ar_nsidx = 0;
 	new->ar_writelen = 0;
-	new->ar_retry.tv_sec = _res.retrans;
+	new->ar_retry.tv_sec = ar_res.retrans;
 	new->ar_retry.tv_usec = 0;
-	new->ar_retries = _res.retry;
+	new->ar_retries = ar_res.retry;
 
 	if (socketpair(AF_UNIX, SOCK_STREAM, 0, new->ar_control) != 0)
 	{
@@ -1169,7 +1215,7 @@ ar_init(ar_malloc_t user_malloc, ar_free_t user_free, void *user_closure,
 		return NULL;
 	}
 
-	new->ar_nsaddrs = TMP_MALLOC(sizeof(struct sockaddr_in) * _res.nscount);
+	new->ar_nsaddrs = TMP_MALLOC(sizeof(struct sockaddr_in) * ar_res.nscount);
 	if (new->ar_nsaddrs == NULL)
 	{
 		TMP_CLOSE(new->ar_control[0]);
@@ -1178,8 +1224,8 @@ ar_init(ar_malloc_t user_malloc, ar_free_t user_free, void *user_closure,
 		TMP_FREE(new);
 		return NULL;
 	}
-	memcpy(new->ar_nsaddrs, _res.nsaddr_list,
-	       sizeof(struct sockaddr_in) * _res.nscount);
+	memcpy(new->ar_nsaddrs, ar_res.nsaddr_list,
+	       sizeof(struct sockaddr_in) * ar_res.nscount);
 
 	if ((new->ar_flags & AR_FLAG_USETCP) != 0)
 	{
@@ -1188,9 +1234,9 @@ ar_init(ar_malloc_t user_malloc, ar_free_t user_free, void *user_closure,
 		struct sockaddr_in sin;
 
 		/* try to connect */
-		for (c = 0; !conn && c < _res.nscount; c++)
+		for (c = 0; !conn && c < ar_res.nscount; c++)
 		{
-			memcpy(&sin, &_res.nsaddr_list[c],
+			memcpy(&sin, &ar_res.nsaddr_list[c],
 			       sizeof(struct sockaddr_in));
 
 			if (connect(new->ar_nsfd, (struct sockaddr *)&sin,
