@@ -1,12 +1,12 @@
 /*
-**  Copyright (c) 2004-2006 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2004-2007 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  $Id: dk.c,v 1.168 2006/06/06 23:22:45 msk Exp $
+**  $Id: dk.c,v 1.173 2007/03/13 18:10:53 msk Exp $
 */
 
 #ifndef lint
-static char dk_c_id[] = "@(#)$Id: dk.c,v 1.168 2006/06/06 23:22:45 msk Exp $";
+static char dk_c_id[] = "@(#)$Id: dk.c,v 1.173 2007/03/13 18:10:53 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -1762,7 +1762,7 @@ dk_header(DK *dk, u_char *hdr, size_t len)
 			q++;
 		}
 
-		if (dk->dk_canonalg == DK_CANON_NOFWS)
+		if (!skipit && dk->dk_canonalg == DK_CANON_NOFWS)
 		{
 			if (q < qend)
 			{
@@ -1890,8 +1890,6 @@ dk_eoh(DK *dk)
 	else
 		hdr = sender;
 
-	/* if we found a signature but the sender doesn't match it, say so */
-
 	/* if verifying and no from/sender header was found, short-circuit */
 	if (hdr == NULL && dk->dk_mode == DK_MODE_VERIFY)
 	{
@@ -1924,6 +1922,7 @@ dk_eoh(DK *dk)
 			return DK_STAT_OK;
 	}
 
+	/* if we found a signature but the sender doesn't match it, say so */
 	if (hdr != NULL)
 	{
 		int status;
@@ -2418,7 +2417,7 @@ dk_eom(DK *dk, DK_FLAGS *dkf)
 		int status;
 
 		/* no sender header was found below the signature */
-		if (dk->dk_skipbody)
+		if (dk->dk_skipbody && dk->dk_processing)
 			return DK_STAT_SYNTAX;
 
 		if (dk->dk_key == NULL)
